@@ -4,6 +4,51 @@ import argparse
 import sys
 import time
 import inspect
+import logging
+import os
+
+from logging.handlers import TimedRotatingFileHandler
+
+
+def init_logger(
+    use_file: bool = False,
+    backup_count: int = 0,  # New parameter: number of log files to retain (0 means keep all)
+) -> logging.Logger:
+    """
+    Automatically names logger after caller's filename, rotates by time, and retains specified number of log files
+
+    Args:
+        use_file: Whether to enable file logging
+        backup_count: Number of historical log files to retain (default 0=keep all)
+    """
+    formatter = logging.Formatter(
+        "%(asctime)s %(filename)s %(levelname)s [line:%(lineno)d] %(message)s",
+        datefmt="%Y-%m-%d %H:%M:%S",
+    )
+    console_handler = logging.StreamHandler()
+    console_handler.setFormatter(formatter)
+    handlers = [console_handler]
+
+    # File handler (daily rotation + file retention policy)
+    if use_file:
+        # Dynamically get caller's filename
+        caller_frame = inspect.stack()[1]
+        caller_path = caller_frame.filename
+        caller_name = os.path.splitext(caller_path)[0]
+        # Configure log directory and filename
+        log_filename = f"{caller_name}.log"
+
+        file_handler = TimedRotatingFileHandler(
+            log_filename,
+            when="midnight",  # Rotate daily
+            interval=1,
+            backupCount=backup_count,  # Key parameter: controls number of retained files
+            encoding="utf-8",
+        )
+        file_handler.setFormatter(formatter)
+        handlers.append(file_handler)
+
+    logging.basicConfig(level=logging.INFO, handlers=handlers)
 
 
 def sleep(seconds, mute=False):
@@ -257,6 +302,7 @@ class SingletonWithArgs:
 
 class ArgMethodBase:
     """auto generator arguments by static methods"""
+    result = True
 
     def __init__(self, epilog=None):
         """initialize arguments parser"""
@@ -279,7 +325,7 @@ class ArgMethodBase:
         elif self.__run_command__(**vars(args)) is False:
             print(color("ERROR", "RED"), file=sys.stderr)
             exit(-1)
-        else:
+        elif self.result:
             print(color("OK", "GREEN"), file=sys.stderr)
 
     def __run_command__(self, command, **args):
@@ -352,12 +398,6 @@ def get_attr_val(obj, *args):
 
 
 if __name__ == "__main__":
-    data = {"a": 1, "b": {"c": 2, "d": [3, 4, {"e": 5}]}, "f": (6, 7, {"g": 8})}
-    n = NestedData(data)
 
-    from pprint import pprint
-
-    pprint(list(n.search("b")))
-    # pprint(list(n.search(1)))
-    # n.show_result()
-    # pprint(list(n.find(lambda k, v: "i" in v, ignore_exc=True)))
+    init_logger()
+    logging.info("test")
